Unification of Selector API
~~~~~~~~~~~~~~~~~~~~~~~~~~~
The API for Selector widgets has been unified to use

- *props* for the properties of the Artist representing the selection.
- *handle_props* for the Artists representing handles for modifying the selection.
- *grab_range* for the maximal tolerance to grab a handle with the mouse.

This affects the following parameters and attributes:


RectangleSelector and EllipseSelector
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
The *maxdist* argument is deprecated, use *grab_range* instead.
The *rectprops* argument is deprecated, use *props* instead.
The *marker_props* argument is deprecated, use *handle_props* instead.

PolygonSelector
^^^^^^^^^^^^^^^
The *vertex_select_radius* argument and attribute is deprecated, use *grab_range* instead.
The *lineprops* argument is deprecated, use *props* instead.
The *markerprops* argument is deprecated, use *handle_props* instead.
The *maxdist* argument and attribute is deprecated, use *grab_range* instead.

SpanSelector
^^^^^^^^^^^^
The *rectprops* argument is deprecated, use *props* instead.
The *maxdist* argument and attribute is deprecated, use *grab_range* instead.

LassoSelector
^^^^^^^^^^^^^
The *lineprops* argument is deprecated, use *props* instead.